Encoding

Struct Encoding 

pub struct Encoding<M = DefaultMode> { /* private fields */ }
Setting up encoding with parameters.

Implementations

Source

impl Encoding

pub const fn new() -> Encoding

Construct a new Encoding instance.

use musli_descriptive::{Encoding};
use musli::{Encode, Decode};
use musli::mode::DefaultMode;

const CONFIG: Encoding<DefaultMode> = Encoding::new();

#[derive(Debug, PartialEq, Encode, Decode)]
struct Struct<'a> {
    name: &'a str,
    age: u32,
}

let mut out = Vec::new();

let expected = Struct {
    name: "Aristotle",
    age: 61,
};

CONFIG.encode(&mut out, &expected)?;
let actual = CONFIG.decode(&out[..])?;

assert_eq!(expected, actual);
Source

impl<M> Encoding<M>
where M: Mode,

pub const fn with_mode<T>(self) -> Encoding<T>
where T: Mode,

Change the mode of the encoding.

pub fn encode_with<C, W, T>( self, cx: &mut C, writer: W, value: &T, ) -> Result<(), <C as Context>::Error>
where C: Context<Input = Error>, W: Writer, Error: From<<W as Writer>::Error>, T: Encode<M> + ?Sized,

Encode the given value to the given Writer using the current configuration.

This is the same as Encoding::encode but allows for using a configurable Context.

pub fn decode_with<'de, C, R, T>( self, cx: &mut C, reader: R, ) -> Result<T, <C as Context>::Error>
where C: Context<Input = Error>, R: Reader<'de>, Error: From<<R as Reader<'de>>::Error>, T: Decode<'de, M>,

Decode the given type T from the given Reader using the current configuration.

This is the same as Encoding::decode but allows for using a configurable Context.

pub fn decode<'de, R, T>(self, reader: R) -> Result<T, Error>
where R: Reader<'de>, Error: From<<R as Reader<'de>>::Error>, T: Decode<'de, M>,

Decode the given type T from the given Reader using the current configuration.

pub fn encode<W, T>(self, writer: W, value: &T) -> Result<(), Error>
where W: Writer, Error: From<<W as Writer>::Error>, T: Encode<M> + ?Sized,

Encode the given value to the given Writer using the current configuration.

pub fn to_vec<T>(self, value: &T) -> Result<Vec<u8>, Error>
where T: Encode<M> + ?Sized,

Encode the given value to a Vec using the current configuration.

pub fn to_vec_with<C, T>( self, cx: &mut C, value: &T, ) -> Result<Vec<u8>, <C as Context>::Error>
where C: Context<Input = Error>, T: Encode<M> + ?Sized,

Encode the given value to a Vec using the current configuration.

This is the same as Encoding::to_vec, but allows for using a configurable Context.

pub fn to_fixed_bytes<const N: usize, T>( self, value: &T, ) -> Result<FixedBytes<N>, Error>
where T: Encode<M> + ?Sized,

Encode the given value to a fixed-size bytes using the current configuration.

pub fn to_fixed_bytes_with<C, const N: usize, T>( self, cx: &mut C, value: &T, ) -> Result<FixedBytes<N>, <C as Context>::Error>
where C: Context<Input = Error>, T: Encode<M> + ?Sized,

Encode the given value to a fixed-size bytes using the current configuration.

pub fn from_slice<'de, T>(self, bytes: &'de [u8]) -> Result<T, Error>
where T: Decode<'de, M>,

Decode the given type T from the given slice using the current configuration.