FixedBytes

Struct FixedBytes 

pub struct FixedBytes<const N: usize> { /* private fields */ }
A fixed-size bytes storage which keeps track of how much has been initialized.

Implementations

Source

impl<const N: usize> FixedBytes<N>

pub const fn new() -> FixedBytes<N>

Construct a new fixed bytes array storage.

pub const fn len(&self) -> usize

Get the length of the collection.

pub const fn is_empty(&self) -> bool

Test if the current container is empty.

pub fn clear(&mut self)

Clear the FixedBytes container.

pub const fn remaining(&self) -> usize

Get the remaining capacity of the FixedBytes.

pub fn into_bytes(self) -> Option<[u8; N]>

Coerce into the underlying bytes if all of them have been initialized.

pub fn as_slice(&self) -> &[u8]

Coerce into the slice of initialized memory which is present.

pub fn as_mut_slice(&mut self) -> &[u8]

Coerce into the mutable slice of initialized memory which is present.

pub fn push(&mut self, value: u8) -> bool

Try and push a single byte.

pub fn extend_from_slice(&mut self, source: &[u8]) -> bool

Try and extend from the given slice.

pub fn write_bytes<C>( &mut self, cx: &mut C, source: &[u8], ) -> Result<(), <C as Context>::Error>
where C: Context<Input = FixedBytesOverflow>,

Try and extend from the given slice.