pub struct FixedBytes<const N: usize> { /* private fields */ }Expand description
A fixed-size bytes storage which keeps track of how much has been initialized.
Implementations
Sourceimpl<const N: usize> FixedBytes<N>
impl<const N: usize> FixedBytes<N>
Sourcepub const fn new() -> FixedBytes<N>
pub const fn new() -> FixedBytes<N>
Construct a new fixed bytes array storage.
Sourcepub fn clear(&mut self)
pub fn clear(&mut self)
Clear the FixedBytes container.
Sourcepub const fn remaining(&self) -> usize
pub const fn remaining(&self) -> usize
Get the remaining capacity of the FixedBytes.
Sourcepub fn into_bytes(self) -> Option<[u8; N]>
pub fn into_bytes(self) -> Option<[u8; N]>
Coerce into the underlying bytes if all of them have been initialized.
Sourcepub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_slice(&self) -> &[u8] ⓘ
Coerce into the slice of initialized memory which is present.
Sourcepub fn as_mut_slice(&mut self) -> &[u8] ⓘ
pub fn as_mut_slice(&mut self) -> &[u8] ⓘ
Coerce into the mutable slice of initialized memory which is present.
Sourcepub fn extend_from_slice(&mut self, source: &[u8]) -> bool
pub fn extend_from_slice(&mut self, source: &[u8]) -> bool
Try and extend from the given slice.
Sourcepub fn write_bytes<C>(
&mut self,
cx: &mut C,
source: &[u8],
) -> Result<(), <C as Context>::Error>where
C: Context<Input = FixedBytesOverflow>,
pub fn write_bytes<C>(
&mut self,
cx: &mut C,
source: &[u8],
) -> Result<(), <C as Context>::Error>where
C: Context<Input = FixedBytesOverflow>,
Try and extend from the given slice.